<?php
namespace Planejamento\Logic\Cardapio\Exception;

/**
 * Created by JetBrains PhpStorm.
 * User: jorgefonseca
 * Date: 15/02/13
 * Time: 11:27
 */
class Cardapio extends \Planejamento\Logic\Exception
{

    private $messageName;

    /**
     * Construtor.
     *
     * Recebe o nome da mensagem cadastrada no setforms.
     *
     * @param string $messageName
     * @param string $message
     * @param int $code
     * @param \Exception|null $previous
     */
    public function __construct($messageName, $message = "", $code = 0, \Exception $previous = null)
    {
        parent::__construct($message, $code, $previous);
        $this->messageName = $messageName;
    }

    /**
     * Retorna o nome da mensagem cadastrada no Setforms para esta excecao.
     *
     * @return string
     */
    public function getMessageName()
    {
        return $this->messageName;
    }

    /**
     * @static
     * @throws Cardapio
     */
    public static function servicoSemConfiguracao()
    {
        throw new self (
            'msg_servico_sem_configuracao',
            'Não existe configuração padrão para o servico selecionado.'
        );
    }

    public static function periodoCardapioBloqueado() {
        throw new self (
            'msg_cardapio_periodo_bloqueado',
            'Período possui cardápio bloqueado.'
        );
    }

    public static function diaNaoUtil() {
        throw new self (
            'msg_cardapio_dia_nao_util',
            'Cardápio bloqueado para dia não útil'
        );
    }

    public static function diaBloqueado() {
        throw new self (
            'msg_cardapio_diaBloqueado',
            tk_get_message_by_name('msg_cardapio_diaBloqueado')
        );
    }

    /**
     * @static
     * @throws Cardapio
     */
    public static function informarComensais()
    {
        throw new self (
            'msg_informar_comensais',
            'Comensal não informado.'
        );
    }

    /**
     * @static
     * @throws Cardapio
     */
    public static function pratoSemReceita()
    {
        throw new self (
            'msg_prato_sem_receita',
            'Prato não possui receita.'
        );
    }

    /**
     * @static
     * @throws Cardapio
     */
    public static function pratoSemReceitaRevisada()
    {
        throw new self (
            'msg_prato_sem_receita_revisada',
            'Operação bloqueada! Prato não possui receita revisada.'
        );
    }

    /**
     * @static
     * @throws Cardapio
     */
    public static function semCardapio()
    {
        throw new self (
            'msg_sem_cardapio',
            'Sem cardápio.'
        );
    }


    public static function custoPadrao() {
        throw new self (
            'msg_servico_sem_custpadr',
            tk_get_message_by_name('msg_servico_sem_custpadr')
        );
    }


    public static function servSemConsFixoCapita() {
        throw new self (
            'msg_pla00100_ServSemConsFixoCapita',
            tk_get_message_by_name('msg_pla00100_ServSemConsFixoCapita')
        );
    }


    public static function qtdComensaisIgualSomaTurno($somaComensais) {
        throw new self (
            'msg_pla00103_comenaisIgualSomaTurno',
            tk_get_message_by_name('msg_pla00103_comenaisIgualSomaTurno',  
                    $somaComensais)
        );
    }

    
    public static function semPrato() {
        throw new self (
            'msg_escolha_prato',
            tk_get_message_by_name('msg_escolha_prato')
        );
    }
    
    public static function semComposicao() {
    	throw new self (
    			'pla00101_naoHaComp',
    			tk_get_message_by_name('pla00101_naoHaComp')
    	);
    }
    
    public static function comensalMenorZero() {
    	throw new self (
    			'msg_pla00101_comensalMenorZero',
    			tk_get_message_by_name('msg_pla00101_comensalMenorZero')
    	);
    }


    public static function naoHaDadosAreaTransf() {
    	throw new self (
    		'msg_pla00101_naoHaDadosAreaTransf',
    		tk_get_message_by_name('msg_pla00101_naoHaDadosAreaTransf')
    	);
    }


    public static function custoForaPeriodo() {
    	throw new self (
    		'msg_pla00101_custoForaPeriodo',
    		tk_get_message_by_name('msg_pla00101_custoForaPeriodo')
    	);
    }

    public static function dtOrigemMenorDtFinalDestino($data){
        throw new self (
            'msg_pla00109_origemMenorDestino',
            tk_get_message_by_name('msg_pla00109_origemMenorDestino', array($data))
        );
    }

    public static function cardOrigemIgualCardDestino(){
        throw new self (
            'msg_pla00109_origemIgualDestino',
            tk_get_message_by_name('msg_pla00109_origemIgualDestino')
        );
    }


    public static function cardapioOrigemSemPrato(){
        throw new self (
            'msg_pla00109_cardOrigSemPrato',
            tk_get_message_by_name('msg_pla00109_cardOrigSemPrato')
        );
    }


    public static function dtOrigemMesmoMes(){
        throw new self (
            'msg_pla00109_dtOrigemMesmoMes',
            tk_get_message_by_name('msg_pla00109_dtOrigemMesmoMes')
        );
    }


    public static function semCardapioPeriodo(){
        throw new self (
            'msg_pla00100_semCardapioPeriodo',
            tk_get_message_by_name('msg_pla00100_semCardapioPeriodo')
        );
    }

}
